pub unsafe extern "C" fn rcl_publisher_is_valid_except_context(
publisher: *const rcl_publisher_t
) -> boolExpand description
Return true if the publisher is valid, otherwise false.
pub unsafe extern "C" fn rcl_publisher_is_valid_except_context(
publisher: *const rcl_publisher_t
) -> boolReturn true if the publisher is valid, otherwise false.